"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
const figlet = require("figlet");
const moment = require("moment");
const ora = require("ora");
const chalk_1 = require("chalk");
const common_1 = require("@nestjs/common");
const table_service_1 = require("../table/table.service");
const result_filter_1 = require("../../util/result-filter");
const stream_1 = require("stream");
let DefaultPresenterService = class DefaultPresenterService {
    constructor(tableService, stream) {
        this.tableService = tableService;
        this.stream = stream;
        this.spinner = null;
    }
    write(str) {
        this.stream.write(str + '\n');
    }
    configure() {
    }
    showFiglet() {
        this.write(figlet.textSync('Github Repo Tools'));
    }
    showGithubTokenInfo(options) {
        const withGithubToken = !!options.token;
        this.write(`Use GITHUB_TOKEN env: ${withGithubToken ? chalk_1.default.green('yes') : chalk_1.default.red('no')}`);
    }
    showRateLimit(rateLimit) {
        if (!rateLimit) {
            return;
        }
        const { limit, remaining, reset } = rateLimit;
        const resetMoment = moment(reset * 1000);
        const resetIn = resetMoment.fromNow();
        const resetAt = resetMoment.format('HH:mm');
        this.write(`Remains ${remaining}/${limit} requests. \nLimit will reset at ${resetAt} (${resetIn})`);
    }
    showError(message) {
        this.write(message);
    }
    showData(report, options) {
        if (!report) {
            this.write('No data found');
            return;
        }
        const filteredReport = report.filter(result_filter_1.getFilter(options));
        const output = this.tableService.format(filteredReport, options);
        this.write(output);
    }
    showSpinner(message) {
        this.spinner = ora({ prefixText: message }).start();
    }
    hideSpinner({ success, message }) {
        if (message) {
            this.spinner.prefixText = message;
        }
        if (success) {
            this.spinner.succeed();
        }
        else {
            this.spinner.fail();
        }
    }
    showSearchNodeVersion({ nvm, engines }) {
        const sources = [nvm && '.nvmrc', engines && 'package.json engines'].filter(x => x).join(' and ');
        this.write(`Search node version from ${sources}`);
    }
    showSearchPackageVersion(packageName) {
        this.write(`NPM package to search: ${chalk_1.default.green(packageName)}`);
    }
};
DefaultPresenterService = __decorate([
    common_1.Injectable(),
    __param(1, common_1.Inject('STREAM')),
    __metadata("design:paramtypes", [table_service_1.TableService,
        stream_1.Writable])
], DefaultPresenterService);
exports.DefaultPresenterService = DefaultPresenterService;
//# sourceMappingURL=default.presenter.service.js.map